aboutsummaryrefslogtreecommitdiff
path: root/src/vectors.s
diff options
context:
space:
mode:
Diffstat (limited to 'src/vectors.s')
-rw-r--r--src/vectors.s4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/vectors.s b/src/vectors.s
index b06f404..b404d98 100644
--- a/src/vectors.s
+++ b/src/vectors.s
@@ -103,7 +103,9 @@
bit PPU::STATUS
- ;; Update the PPU control register with the shadowed value.
+ ;; Update the PPU control/mask registers with shadowed values.
+ lda PPU::zp_mask
+ sta PPU::MASK
lda PPU::zp_control
sta PPU::CONTROL